# This is a -*- Tcl -*- library script and belongs to the
# `Jumble Library for Tcl and Friends'.
#
# array.tcl --- Array manipulation functions
#
# Copyright (C) 1997 Stefan Hornburg
#
# Author: Stefan Hornburg <racke@gundel.han.de>
# Maintainer: Stefan Hornburg <racke@gundel.han.de>
# Version: 0.0a3
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
# 
# This file is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this file; see the file COPYING.  If not, write to the Free
# Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

# -----------------------------------------------------------
# juf_array_values [SWITCH] NAME
#
# Returns a list containing the values of all of the elements
# in the array NAME.
# If SWITCH equals to `-unique', a specific value appears
# only once in the list
# -----------------------------------------------------------

proc juf_array_values {args} {
	set v_len [llength $args]
	#
	# Check number of arguments
	#
	if {$v_len == 0 || $v_len > 2} {
		error "wrong # args: should be \"juf_array_values ?-unique? name\""
	}
	#
	# Process switches, if any
	#
	if {$v_len == 2} {
		if {[lindex $args 0] != "-unique"} {
			error "bad switch \"[lindex $args 0]\": must be -unique"
		}
		set v_unique 1
	} else {
		set v_unique 0
	}
	upvar [lindex $args end] v_name
	#
	# Build list with the help of an auxiliary array
	#
	set v_list ""
	foreach v_el [array names v_name] {
		set v_val $v_name($v_el)
		if {![info exists v_arr($v_val)] || !$v_unique} {
			lappend v_list $v_val
		} 
		#
		# Create array element for this value
		#
		set v_arr($v_val) ""
	}
	set v_list
}

