# This is a -*- Tcl -*- library script and belongs to the
# `Jumble Library for Tcl and Friends'.
#
# file.tcl --- Manipulating files
#
# Copyright (C) 1996, 1997 Stefan Hornburg
#
# Author: Stefan Hornburg <racke@gundel.han.de>
# Maintainer: Stefan Hornburg <racke@gundel.han.de>
# Version: 0.0a3
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
# 
# This file is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this file; see the file COPYING.  If not, write to the Free
# Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

# ----------------------
# Create new debug flags
# ----------------------

juf_dbg_add_flags {
	juf_flags_file juf_flags_file_enter juf_flags_file_mkdir
	juf_flags_file_iscwd
}

# ---------------------------------------------------------
# juf_file_slurp - reads complete file into single variable
#
# in:	file	name of file
#		name	name of variable
#
# out:  1 in case of success, 0 otherwise
# ---------------------------------------------------------

proc juf_file_slurp {file name} {
	upvar $name v_buf
	#
	# open file
	#
	if {[catch "open $file" v_chl] != 0} {
		juf_err_err $file [juf_err_tclmsg]
		return 0
	}
	#
	# read contents
	#
	if {[catch "read $v_chl" v_buf] != 0} {
		juf_err_err $file [juf_err_tclmsg]
		return 0
	}
	close $v_chl
	return 1
}

# --------------------------------------------------------------
# juf_file_mkdirs_aux - auxiliary function for juf_file_mkdirs
# --------------------------------------------------------------

proc juf_file_mkdirs_aux {dir} {
	if {$dir == "/"} {return 1}
	if {! [juf_file_mkdirs_aux [file dirname $dir]]} {return 0}
	juf_dbg_out juf_flags_file_enter "Checking for directory $dir"
	if [file exists $dir] {
		return 1
	} else {
		juf_dbg_out juf_flags_file_mkdir "Creating directory $dir"
		if {[catch "exec mkdir $dir"] != 0} {
			err_fat $dir 
		}		
		return 1
	}
}

# -------------------------------------------------------------------------
# juf_file_mkdirs - make directories 
#
# in:	$args	list of directories
# out:	1 if successful, 0 otherwise
#
# Creates any missing parent directories for each argument.
# Do not consider an argument directory that already exists to be an error.
# -------------------------------------------------------------------------

proc juf_file_mkdirs {args} {
	foreach dir $args {
		if {! [juf_file_mkdirs_aux $dir]} {
			return 0
		}
	}
}

# -------------------------------------------------
# juf_file_iscwd - checks if filename corresponds
# 					to current working directory
#
# in:	$name 	filename to be checked
# out:  1 if successful, 0 otherwise
# -------------------------------------------------

proc juf_file_iscwd {name} {
	if {[file isdir $name]} {
		set cwd [pwd]	;# remember current working directory
		juf_dbg_out juf_flags_file_iscwd\
				"Current working directory is $cwd"
		cd $name		;# move to proposed directory
		juf_dbg_out juf_flags_file_iscwd\
				"Checked directory is [pwd]"
		if {[pwd] == $cwd} {
			return 1
		} else {
			cd $cwd		;# restore working directory
			return 0
		}
	} else {
		juf_dbg_out juf_flags_file_iscwd $name "Not a directory"
		return 0
	}
}





